@@ -48,6 +48,7 @@
 #include "pluma-tab-label.h"
 #include "pluma-marshal.h"
 #include "pluma-window.h"
+#include "pluma-prefs-manager.h"
 
 #define AFTER_ALL_TABS -1
 #define NOT_IN_APP_WINDOWS -2
@@ -81,6 +82,7 @@ static void move_current_tab_to_another_notebook  (PlumaNotebook  *src,
 
 /* Local variables */
 static GdkCursor *cursor = NULL;
+static gboolean leftdown = FALSE;
 
 /* Signals */
 enum
@@ -389,12 +391,18 @@ static void
 drag_start (PlumaNotebook *notebook,
 	    guint32        time)
 {
+	if (!leftdown) return;
+
 	notebook->priv->drag_in_progress = TRUE;
 
 	/* get a new cursor, if necessary */
 	/* FIXME multi-head */
 	if (cursor == NULL)
-		cursor = gdk_cursor_new (GDK_FLEUR);
+	{
+		GdkDisplay *display;
+		display = gtk_widget_get_display (GTK_WIDGET (notebook));
+		cursor = gdk_cursor_new_for_display (display, GDK_FLEUR);
+	}
 
 	/* grab the pointer */
 	gtk_grab_add (GTK_WIDGET (notebook));
@@ -552,6 +560,8 @@ button_release_cb (PlumaNotebook  *notebook,
 		   GdkEventButton *event,
 		   gpointer        data)
 {
+	if (event->button == 1) leftdown = FALSE;
+
 	if (notebook->priv->drag_in_progress)
 	{
 		gint cur_page_num;
@@ -607,6 +617,8 @@ button_press_cb (PlumaNotebook  *notebook,
 	    (event->type == GDK_BUTTON_PRESS) && 
 	    (tab_clicked >= 0))
 	{
+		leftdown = TRUE;
+
 		notebook->priv->x_start = event->x_root;
 		notebook->priv->y_start = event->y_root;
 		
@@ -630,6 +642,11 @@ button_press_cb (PlumaNotebook  *notebook,
 		}
 		else
 		{
+			if (leftdown) {
+				leftdown = FALSE;
+				return TRUE;
+			}
+
 			/* Switch to the page the mouse is over, but don't consume the event */
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 
 						       tab_clicked);
@@ -640,12 +657,12 @@ button_press_cb (PlumaNotebook  *notebook,
 	{
 		if (event->type == GDK_BUTTON_PRESS)
 		{
-			tab1click = gtk_notebook_get_current_page (notebook);
+			tab1click = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
 			newfile = (tab_clicked == -1);
 		}
 		else if (event->type == GDK_2BUTTON_PRESS)
 		{
-			if ((tab1click != gtk_notebook_get_current_page (notebook)) ||
+			if ((tab1click != gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))) ||
 			    (tab_clicked >= 0) || ((tab_clicked == -1) && (!newfile)))
 				return TRUE;
 
@@ -705,8 +722,9 @@ static void
 update_tabs_visibility (PlumaNotebook *nb, 
 			gboolean       before_inserting)
 {
-	gboolean show_tabs;
-	guint num;
+	gboolean   show_tabs;
+	guint      num;
+	GSettings *settings;
 
 	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 
@@ -714,7 +732,17 @@ update_tabs_visibility (PlumaNotebook *nb,
 
 	show_tabs = (nb->priv->always_show_tabs || num > 1);
 
-	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
+	settings = g_settings_new ("org.mate.pluma");
+
+	if (g_settings_get_boolean (settings, "show-tabs-with-side-pane"))
+		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
+	else
+	{
+		if (pluma_prefs_manager_get_side_pane_visible ())
+			gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), FALSE);
+		else
+			gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
+	}
 }
 
 static void
